# Minimus

Инструмент для ведения заметок. Если у вас есть каталог с записями, minimus
поможет сшить документы между собой с помощью тегов. А ещё он сделает стартовую
страницу, с которой можно будет перейти на любой документ.

## Как пользоваться

Надо иметь на машине установленный python версией 3.10 или новее.

Установка Минимуса:

```shell
pip install minimus
```

После этого можно перейти в корневой каталог с заметками и вызвать minimus в
терминале:

```shell
minimus
```

Или:

```shell
min
```

Или:

```shell
minimus .
```

Можно также никуда не переходить и сообщить программе целевой каталог:

```shell
minimus "C:\\Заметки"
```

### Требования к заметкам

Заметки должны быть в формате ".md", а теги надо отмечать двойными фигурными
скобками. Программа заменит их ссылками на соответствующие файлы. Теги можно
располагать где угодно в тексте. Следите только за тем, чтобы написание было
всегда одинаковым.

До использования:

```markdown
# Мышь

Маленькое млекопитающее.

---

Теги:

- {{ Хвост }}
- {{ 4 лапы }}
- {{ Серый }}

---

Живёт почти везде.
```

После:

```markdown
# Мышь

Маленькое млекопитающее.

---

Теги:

- [{{ Хвост }}](../_tags/hvost.md)
- [{{ 4 лапы }}](../_tags/4_lapi.md)
- [{{ Серый }}](../_tags/seriy.md)

---

Живёт почти везде.
```

Нормальный вывод программы выглядит примерно вот так:

```
-------------------------------------------------------------------------------
███╗   ███╗██╗███╗   ██╗██╗███╗   ███╗██╗   ██╗███████╗    ██████╗     ██████╗ 
████╗ ████║██║████╗  ██║██║████╗ ████║██║   ██║██╔════╝    ╚════██╗   ██╔═████╗
██╔████╔██║██║██╔██╗ ██║██║██╔████╔██║██║   ██║███████╗     █████╔╝   ██║██╔██║
██║╚██╔╝██║██║██║╚██╗██║██║██║╚██╔╝██║██║   ██║╚════██║    ██╔═══╝    ████╔╝██║
██║ ╚═╝ ██║██║██║ ╚████║██║██║ ╚═╝ ██║╚██████╔╝███████║    ███████╗██╗╚██████╔╝
╚═╝     ╚═╝╚═╝╚═╝  ╚═══╝╚═╝╚═╝     ╚═╝ ╚═════╝ ╚══════╝    ╚══════╝╚═╝ ╚═════╝ 
-------------------------------------------------------------------------------
Исходный каталог: /home/test-minimus

Сохранение заметок
        +++ Сохранён: 2020-07-06_recursion.md
        +++ Сохранён: 2020-07-06_vacuum.md
        +++ Сохранён: Животные/2020-07-06_elephant.md
        +++ Сохранён: Животные/2020-07-06_mouse.md

Сохранение тегов
        Сохранено тегов: 5 шт. 

Генерация вспомогательных файлов
        Сохранён: /home/test-minimus/README.md
        Сохранён: /home/test-minimus/.minimus_cache.json
-------------------------------------------------------------------------------
Обработка заняла 0.02 сек.
```
